package com.ruoyi.branch.service;

import java.util.List;
import com.ruoyi.branch.domain.TBranchPublicize;

/**
 * 支部园地宣传Service接口
 * 
 * @author ruoyi
 * @date 2023-07-27
 */
public interface ITBranchPublicizeService 
{
    /**
     * 查询支部园地宣传
     * 
     * @param publicizeId 支部园地宣传主键
     * @return 支部园地宣传
     */
    public TBranchPublicize selectTBranchPublicizeByPublicizeId(Long publicizeId);

    /**
     * 查询支部园地宣传列表
     * 
     * @param tBranchPublicize 支部园地宣传
     * @return 支部园地宣传集合
     */
    public List<TBranchPublicize> selectTBranchPublicizeList(TBranchPublicize tBranchPublicize);

    /**
     * 新增支部园地宣传
     * 
     * @param tBranchPublicize 支部园地宣传
     * @return 结果
     */
    public int insertTBranchPublicize(TBranchPublicize tBranchPublicize);

    /**
     * 修改支部园地宣传
     * 
     * @param tBranchPublicize 支部园地宣传
     * @return 结果
     */
    public int updateTBranchPublicize(TBranchPublicize tBranchPublicize);

    /**
     * 批量删除支部园地宣传
     * 
     * @param publicizeIds 需要删除的支部园地宣传主键集合
     * @return 结果
     */
    public int deleteTBranchPublicizeByPublicizeIds(Long[] publicizeIds);

    /**
     * 删除支部园地宣传信息
     * 
     * @param publicizeId 支部园地宣传主键
     * @return 结果
     */
    public int deleteTBranchPublicizeByPublicizeId(Long publicizeId);
}
