package com.ruoyi.web.controller.branch;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.branch.domain.TFile;
import com.ruoyi.branch.service.ITFileService;
import com.ruoyi.web.controller.branch.vo.ProfilesVO;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.branch.domain.TBranchPublicize;
import com.ruoyi.branch.service.ITBranchPublicizeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 支部园地宣传Controller
 * 
 * @author ruoyi
 * @date 2023-07-27
 */
@RestController
@RequestMapping("/branch/publicize")
public class TBranchPublicizeController extends BaseController
{
    @Autowired
    private ITBranchPublicizeService tBranchPublicizeService;

    @Autowired
    private ITFileService fileService;

    /**
     * 查询首页置顶图片轮播
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:list')")
    @GetMapping("/listProfiles")
    public AjaxResult listProfiles()
    {
        TBranchPublicize tBranchPublicize = new TBranchPublicize();
        tBranchPublicize.setIsPinned("1");
        List<TBranchPublicize> tBranchPublicizes = tBranchPublicizeService.selectTBranchPublicizeList(tBranchPublicize);
        List<ProfilesVO> profileVOs = new ArrayList<>();
        for (TBranchPublicize branchPublicize : tBranchPublicizes) {
            TFile tFile = new TFile();
            tFile.setTableName("branchPublicize");
            tFile.setTableId(branchPublicize.getPublicizeId());
            List<TFile> tFiles = fileService.selectTFileList(tFile);

            TFile tFile2 = new TFile();
            tFile2.setTableName("branchPub2");
            tFile2.setTableId(branchPublicize.getPublicizeId());
            List<TFile> tFiles2 = fileService.selectTFileList(tFile2);

            if (tFiles != null) {
                TFile file = tFiles.get(0);
                TFile file2 = tFiles2.get(0);
                ProfilesVO vo = new ProfilesVO();
                vo.setUrl(file.getUrl());
                vo.setUrl2(file2.getUrl());
                vo.setTitle(branchPublicize.getPublicizeTitle());
                profileVOs.add(vo);
            }
        }
        return AjaxResult.success(profileVOs);
    }

    /**
     * 查询支部园地宣传列表
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:list')")
    @GetMapping("/list")
    public TableDataInfo list(TBranchPublicize tBranchPublicize)
    {
        startPage();
        List<TBranchPublicize> list = tBranchPublicizeService.selectTBranchPublicizeList(tBranchPublicize);
        return getDataTable(list);
    }

    /**
     * 导出支部园地宣传列表
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:export')")
    @Log(title = "支部园地宣传", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TBranchPublicize tBranchPublicize)
    {
        List<TBranchPublicize> list = tBranchPublicizeService.selectTBranchPublicizeList(tBranchPublicize);
        ExcelUtil<TBranchPublicize> util = new ExcelUtil<TBranchPublicize>(TBranchPublicize.class);
        util.exportExcel(response, list, "支部园地宣传数据");
    }

    /**
     * 获取支部园地宣传详细信息
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:query')")
    @GetMapping(value = "/{publicizeId}")
    public AjaxResult getInfo(@PathVariable("publicizeId") Long publicizeId)
    {
        return success(tBranchPublicizeService.selectTBranchPublicizeByPublicizeId(publicizeId));
    }

    /**
     * 新增支部园地宣传
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:add')")
    @Log(title = "支部园地宣传", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TBranchPublicize tBranchPublicize)
    {
        tBranchPublicize.setCreateBy(getUsername());
        return toAjax(tBranchPublicizeService.insertTBranchPublicize(tBranchPublicize));
    }

    /**
     * 修改支部园地宣传
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:edit')")
    @Log(title = "支部园地宣传", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TBranchPublicize tBranchPublicize)
    {
        return toAjax(tBranchPublicizeService.updateTBranchPublicize(tBranchPublicize));
    }

    /**
     * 删除支部园地宣传
     */
    @PreAuthorize("@ss.hasPermi('branch:publicize:remove')")
    @Log(title = "支部园地宣传", businessType = BusinessType.DELETE)
	@DeleteMapping("/{publicizeIds}")
    public AjaxResult remove(@PathVariable Long[] publicizeIds)
    {
        return toAjax(tBranchPublicizeService.deleteTBranchPublicizeByPublicizeIds(publicizeIds));
    }
}
